@@ -5,7 +5,7 @@
  * This file defines Horde's core API interface. Other core Horde libraries
  * can interact with Horde through this API.
  *
- * Copyright 2010-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -21,7 +21,7 @@
 
 /* Determine the base directories. */
 if (!defined('GOLLEM_BASE')) {
-    define('GOLLEM_BASE', __DIR__ . '/..');
+    define('GOLLEM_BASE', realpath(__DIR__ . '/..'));
 }
 
 if (!defined('HORDE_BASE')) {
@@ -30,7 +30,7 @@ if (!defined('HORDE_BASE')) {
     if (file_exists(GOLLEM_BASE . '/config/horde.local.php')) {
         include GOLLEM_BASE . '/config/horde.local.php';
     } else {
-        define('HORDE_BASE', GOLLEM_BASE . '/..');
+        define('HORDE_BASE', realpath(GOLLEM_BASE . '/..'));
     }
 }
 
@@ -50,7 +50,7 @@ class Gollem_Application extends Horde_Registry_Application
 
     /**
      */
-    public $version = 'H5 (3.0.1)';
+    public $version = 'H5 (3.0.3)';
 
     /**
      * Server key used in logged out session.
