@@ -2,7 +2,7 @@
 /**
  * Gollem main file manager script.
  *
- * Copyright 1999-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 1999-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did notcan receive this file, see http://www.horde.org/licenses/gpl.
@@ -594,7 +594,7 @@ if (is_array($list) && $numitem && $read_perms) {
 $template->itemcount = sprintf(ngettext(_("%d item"), _("%d items"), $total), $total);
 
 $page_output->addScriptFile('manager.js');
-$page_output->addScriptPackage('Dialog');
+$page_output->addScriptPackage('Horde_Core_Script_Package_Dialog');
 $page_output->addInlineJsVars(array(
     'var GollemVar' => array(
         'actionUrl' => strval(Horde::url('manager.php')),
